@@ -107,6 +107,15 @@ set_recent_entry (ScreenshotApplication *self)
   g_free (app_exec);
 }
 
+static void
+screenshot_close_interactive_dialog (ScreenshotApplication *self)
+{
+  ScreenshotDialog *dialog = self->priv->dialog;
+  save_folder_to_settings (self);
+  gtk_widget_destroy (dialog->dialog);
+  g_free (dialog);
+}
+
 static void
 save_pixbuf_handle_success (ScreenshotApplication *self)
 {
@@ -114,11 +123,7 @@ save_pixbuf_handle_success (ScreenshotApplication *self)
 
   if (screenshot_config->interactive)
     {
-      ScreenshotDialog *dialog = self->priv->dialog;
-
-      save_folder_to_settings (self);
-      gtk_widget_destroy (dialog->dialog);
-      g_free (dialog);
+      screenshot_close_interactive_dialog (self);
     }
   else
     {
@@ -381,6 +386,13 @@ screenshot_save_to_file (ScreenshotApplication *self)
   g_object_unref (target_file);
 }
 
+static void
+screenshot_back (ScreenshotApplication *self)
+{
+  screenshot_close_interactive_dialog (self);
+  screenshot_show_interactive_dialog (self);
+}
+
 static void
 screenshot_save_to_clipboard (ScreenshotApplication *self)
 {
@@ -406,6 +418,9 @@ screenshot_dialog_response_cb (ScreenshotResponse response,
     case SCREENSHOT_RESPONSE_COPY:
       screenshot_save_to_clipboard (self);
       break;
+    case SCREENSHOT_RESPONSE_BACK:
+      screenshot_back (self);
+      break;
     default:
       g_assert_not_reached ();
       break;
